@@ -1,9 +1,8 @@
 "conversions retaining to ints"
 
 import json, os
-data = json.load(open(f"{os.path.realpath(__file__)}/intConversions.json","r"))
+data = json.load(open(f"{os.path.dirname(os.path.realpath(__file__))}/intConversions.json","r"))
 "convig data from json"
-print(data)
 
 def baseN(num,b,numerals=data["baseKeys"]): # from https://stackoverflow.com/questions/2267362/how-to-convert-an-integer-to-a-string-in-any-base writen by jellyfishtree
     """convert to sys with base b
@@ -44,7 +43,3 @@ def convertTointFrombaseStr(num, b, numerals=data["baseKeys"]):
     for idx, key in enumerate(num):
         res += b**(len(num) - idx-1)*(numerals.index(key))
     return res
-
-
-var = baseN(8347598242, 64)
-print(var, convertTointFrombaseStr(var, 64))
\ No newline at end of file
