@@ -1,6 +1,6 @@
 """additons to paralel computation
 
 additional and slitly imporved thread"""
-from jpe_types.paralel.thread import Thread, LockableThread, threadInharitanceFilter
+from jpe_types.paralel.thread import Thread, LockableThread, threadInharitanceFilter, LogThread
 
 #__all__ = ["Thread", "LockableThread", "threadInharitanceFilter"]
\ No newline at end of file
